[Scummvm-cvs-logs] SF.net SVN: scummvm:[55433] scummvm/trunk/engines/mohawk

mthreepwood at users.sourceforge.net mthreepwood at users.sourceforge.net
Sat Jan 22 17:35:25 CET 2011


Revision: 55433
          http://scummvm.svn.sourceforge.net/scummvm/?rev=55433&view=rev
Author:   mthreepwood
Date:     2011-01-22 16:35:25 +0000 (Sat, 22 Jan 2011)

Log Message:
-----------
MOHAWK: Fix meaning of the sound loop variable

Modified Paths:
--------------
    scummvm/trunk/engines/mohawk/sound.cpp
    scummvm/trunk/engines/mohawk/sound.h

Modified: scummvm/trunk/engines/mohawk/sound.cpp
===================================================================
--- scummvm/trunk/engines/mohawk/sound.h	2011-01-22 16:29:54 UTC (rev 55432)
+++ scummvm/trunk/engines/mohawk/sound.h	2011-01-22 16:35:25 UTC (rev 55433)
@@ -110,7 +110,7 @@
 	byte bitsPerSample;
 	byte channels;
 	uint16 encoding;
-	uint16 loop;
+	uint16 loopCount; // 0 == no looping, 0xFFFF == infinite loop
 	uint32 loopStart;
 	uint32 loopEnd;
 	Common::SeekableReadStream *audioData;


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/mohawk/sound.cpp	2011-01-22 16:29:54 UTC (rev 55432)
+++ scummvm/trunk/engines/mohawk/sound.cpp	2011-01-22 16:35:25 UTC (rev 55433)
@@ -440,15 +440,15 @@
 			dataChunk.bitsPerSample = stream->readByte();
 			dataChunk.channels = stream->readByte();
 			dataChunk.encoding = stream->readUint16BE();
-			dataChunk.loop = stream->readUint16BE();
+			dataChunk.loopCount = stream->readUint16BE();
 			dataChunk.loopStart = stream->readUint32BE();
 			dataChunk.loopEnd = stream->readUint32BE();
 
 			// NOTE: We currently ignore all of the loop parameters here. Myst uses the loop
 			// variable but the loopStart and loopEnd are always 0 and the size of the sample.
 			// Myst ME doesn't use the Mohawk Sound format and just standard WAVE files and
 			// therefore does not contain any of this metadata and we have to specify whether
 			// or not to loop elsewhere.
 
 			dataChunk.audioData = stream->readStream(dataSize);
 			break;
@@ -440,15 +440,15 @@
 			dataChunk.loopEnd = stream->readUint32BE();
 
-			// NOTE: We currently ignore all of the loop parameters here. Myst uses the loop
-			// variable but the loopStart and loopEnd are always 0 and the size of the sample.
-			// Myst ME doesn't use the Mohawk Sound format and just standard WAVE files and
-			// therefore does not contain any of this metadata and we have to specify whether
-			// or not to loop elsewhere.
+			// NOTE: We currently ignore all of the loop parameters here. Myst uses the
+			// loopCount variable but the loopStart and loopEnd are always 0 and the size of
+			// the sample. Myst ME doesn't use the Mohawk Sound format and just standard WAVE
+			// files and therefore does not contain any of this metadata and we have to specify
+			// whether or not to loop elsewhere.
 
 			dataChunk.audioData = stream->readStream(dataSize);

Modified: scummvm/trunk/engines/mohawk/sound.h
===================================================================